@@ -12,6 +12,10 @@ namespace procman
         OptionGroup();
 
         bool show_system_tab;
+        bool show_processes_tab;
+        bool show_resources_tab;
+        bool show_file_systems_tab;
+        bool print_version;
     };
 }
 
