@@ -174,7 +174,8 @@ update_openfiles_dialog (GtkWidget *tree)
     GHashTable *new_maps;
     guint i;
 
-    info = static_cast<ProcInfo*>(g_object_get_data (G_OBJECT (tree), "selected_info"));
+    pid_t pid = GPOINTER_TO_UINT(static_cast<pid_t*>(g_object_get_data (G_OBJECT (tree), "selected_info")));
+    info = ProcInfo::find(pid);
 
     if (!info)
         return;
@@ -353,7 +354,7 @@ create_single_openfiles_dialog (GtkTreeModel *model, GtkTreePath *path,
 
     tree = create_openfiles_tree (app);
     gtk_container_add (GTK_CONTAINER (scrolled), tree);
-    g_object_set_data (G_OBJECT (tree), "selected_info", info);
+    g_object_set_data (G_OBJECT (tree), "selected_info", GUINT_TO_POINTER (info->pid));
     g_object_set_data (G_OBJECT (tree), "settings", app->settings);
 
     g_signal_connect (G_OBJECT (openfilesdialog), "response",
