@@ -111,8 +111,9 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
 {
     guint i;
     GtkListStore *store;
-
-    get_process_memory_info(info);
+    
+    if (!info)
+        return;
 
 #if defined (__OpenBSD__)
     struct clockinfo cinf;
@@ -167,10 +168,8 @@ update_procproperties_dialog (GtkWidget *tree)
 {
     ProcInfo *info;
 
-    info = static_cast<ProcInfo*>(g_object_get_data (G_OBJECT (tree), "selected_info"));
-
-    if (!info)
-        return;
+    pid_t pid = GPOINTER_TO_UINT(static_cast<pid_t*>(g_object_get_data (G_OBJECT (tree), "selected_info")));
+    info = ProcInfo::find(pid);
 
     fill_proc_properties(tree, info);
 }
@@ -291,7 +290,7 @@ create_single_procproperties_dialog (GtkTreeModel *model, GtkTreePath *path,
 
     tree = create_procproperties_tree (app);
     gtk_container_add (GTK_CONTAINER (scrolled), tree);
-    g_object_set_data (G_OBJECT (tree), "selected_info", info);
+    g_object_set_data (G_OBJECT (tree), "selected_info", GUINT_TO_POINTER (info->pid));
 
     gtk_box_pack_start (GTK_BOX (dialog_vbox), scrolled, TRUE, TRUE, 0);
     gtk_widget_show_all (scrolled);
